@@ -3,12 +3,12 @@ BEGIN {
   $Bio::GFF3::Transform::FromFasta::AUTHORITY = 'cpan:RBUELS';
 }
 BEGIN {
-  $Bio::GFF3::Transform::FromFasta::VERSION = '0.3';
+  $Bio::GFF3::Transform::FromFasta::VERSION = '0.4';
 }
 # ABSTRACT: make gff3 for the sequences in a fasta file
 
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use Carp;
 use Scalar::Util 'blessed';
 
@@ -83,13 +83,15 @@ sub _for_fasta {
 
 sub _to_filehandle {
     my ( $thing, $mode ) = @_;
+
     return $thing if
-        ref $thing
+           $thing
+        && ref $thing
         && (    ref $thing eq 'GLOB'
              || blessed $thing && $thing->can('print')
            );
 
-    open( my $f, ($mode || '<'), $thing) or die "$! opening $thing";
+    open( my $f, ($mode || '<'), $thing) or confess "$! opening $thing";
     return $f;
 }
 
